@@ -78,7 +78,7 @@ openapi_schema = {
 
 def test_openapi():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
