@@ -10,10 +10,10 @@ def test_main():
 
     client = TestClient(app)
     response = client.get("/items/foo")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert b"<h1>Item ID: foo</h1>" in response.content
     response = client.get("/static/styles.css")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert b"color: green;" in response.content
     shutil.rmtree("./templates")
     shutil.rmtree("./static")
